# MetaView

Viewer and Editor for Image Metadata

## Features
- View metadata of images
- Edit metadata of images
- Support for various image formats
- User-friendly interface

## Installation

To install MetaView, download from PyPI:

```bash
pip install metaview
```

## Usage
To use MetaView, you can run the following command in your terminal:

```bash
python -m metaview
```